* Stop syntax and large titles from printing to output.
SET PRINTBACK=NONE HEADER=NO.

***********************************************************************************.
*******             BEGIN DATA MANIPULATION OF CHAPTER 4 EXAMPLE            *******.
*******                  CHANGE "filesave" to your directory                *******.
***********************************************************************************.

* Define location of files used in code below.
FILE HANDLE filesave /NAME = "C:\Dropbox\PilesOfVariance\Chapter4\SPSS".

* Import chapter 4 stacked data.
GET FILE = "filesave/SPSS_Chapter4.sav".
DATASET NAME Chapter4 WINDOW=FRONT.

***********************************************************************************.
*******                     BEGIN CHAPTER 4 MODELS                          *******.
*******    NOTE: NOT ALL MODELS WILL BE POSSIBLE TO ESTIMATE IN SPSS        *******.
***********************************************************************************.

* Open output directory.
OUTPUT NAME SPSS_Chapter4_Output.

ECHO "Chapter 4 Example: Means by StudyDay for Positive Mood outcome".
SUMMARIZE
   /TABLES = posmood BY studyday
   /FORMAT = NOLIST TOTAL 
   /CELLS  = COUNT MEAN SEMEAN MIN MAX.

DATASET ACTIVATE Chapter4 WINDOW=FRONT.
ECHO 'Ch 4: Saturated Means, Unstructured R-Only Model;'.
ECHO 'Test for mean differences across days'.
MIXED posmood BY PersonID studyday
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV R 
     /FIXED    = studyday 
     /REPEATED = studyday | COVTYPE(UN) SUBJECT(PersonID)
     /EMMEANS  = TABLES(studyday) COMPARE(studyday)
.
 
DATASET ACTIVATE Chapter4 WINDOW=FRONT.
ECHO 'Ch 4: Empty Means, Unstructured R-Only Model;'.
ECHO 'Best-fitting and least parsimonious baseline'.
MIXED posmood BY PersonID studyday
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV R 
     /FIXED    =  
     /REPEATED = studyday | COVTYPE(UN) SUBJECT(PersonID)
.
 
DATASET ACTIVATE Chapter4 WINDOW=FRONT.
ECHO 'Ch 4: Empty Means, Compound Symmetry R-Only Model;'.
ECHO 'Worst-fitting and most parsimonious baseline'.
MIXED posmood BY PersonID studyday
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV R 
     /FIXED    =  
     /REPEATED = studyday | COVTYPE(CS) SUBJECT(PersonID)
.
 
DATASET ACTIVATE Chapter4 WINDOW=FRONT.
ECHO 'Ch 4: Empty Means, Compound Symmetry Heterogeneous R-Only Model'.
MIXED posmood BY PersonID studyday
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV R 
     /FIXED    =  
     /REPEATED = studyday | COVTYPE(CSH) SUBJECT(PersonID)
.
 
DATASET ACTIVATE Chapter4 WINDOW=FRONT.
ECHO 'Ch 4: Empty Means, First-Order Auto-Regressive R-Only Model'.
MIXED posmood BY PersonID studyday
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV R 
     /FIXED    =  
     /REPEATED = studyday | COVTYPE(AR1) SUBJECT(PersonID)
.
 
DATASET ACTIVATE Chapter4 WINDOW=FRONT.
ECHO 'Ch 4: Empty Means, First-Order Auto-Regressive Heterogeneous R-Only Model'.
MIXED posmood BY PersonID studyday
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV R 
     /FIXED    =  
     /REPEATED = studyday | COVTYPE(ARH1) SUBJECT(PersonID)
.
 
DATASET ACTIVATE Chapter4 WINDOW=FRONT.
ECHO 'Ch 4: Empty Means, n-1 Lag Toeplitz R-Only Model'.
MIXED posmood BY PersonID studyday
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV R 
     /FIXED    =  
     /REPEATED = studyday | COVTYPE(TP) SUBJECT(PersonID)
.
 
DATASET ACTIVATE Chapter4 WINDOW=FRONT.
ECHO 'Ch 4: Empty Means, n-1 Lag Toeplitz Heterogeneous R-Only Model'.
MIXED posmood BY PersonID studyday
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV R 
     /FIXED    =  
     /REPEATED = studyday | COVTYPE(TPH) SUBJECT(PersonID)
.
 
DATASET ACTIVATE Chapter4 WINDOW=FRONT.
ECHO 'Ch 4: Empty Means, Random Intercept in G;'.
ECHO 'Diagonal R'.
MIXED posmood BY PersonID studyday
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV G R 
     /FIXED    =  
     /RANDOM   = INTERCEPT | COVTYPE(UN) SUBJECT(PersonID)
     /REPEATED = studyday | COVTYPE(ID) SUBJECT(PersonID)
.
 
DATASET ACTIVATE Chapter4 WINDOW=FRONT.
ECHO 'Ch 4: Empty Means, Random Intercept in G;'.
ECHO 'Diagonal Heterogeneous R'.
MIXED posmood BY PersonID studyday
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV G R 
     /FIXED    =  
     /RANDOM   = INTERCEPT | COVTYPE(UN) SUBJECT(PersonID)
     /REPEATED = studyday | COVTYPE(DIAG) SUBJECT(PersonID)
.
 
DATASET ACTIVATE Chapter4 WINDOW=FRONT.
ECHO 'Ch 4: Empty Means, Random Intercept in G;'.
ECHO 'First-Order Autoregressive R'.
MIXED posmood BY PersonID studyday
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV G R 
     /FIXED    =  
     /RANDOM   = INTERCEPT | COVTYPE(UN) SUBJECT(PersonID)
     /REPEATED = studyday | COVTYPE(AR1) SUBJECT(PersonID)
.
 
DATASET ACTIVATE Chapter4 WINDOW=FRONT.
ECHO 'Ch 4: Empty Means, Random Intercept in G;'.
ECHO 'First-Order Autoregressive Heterogeneous R'.
MIXED posmood BY PersonID studyday
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV G R 
     /FIXED    =  
     /RANDOM   = INTERCEPT | COVTYPE(UN) SUBJECT(PersonID)
     /REPEATED = studyday | COVTYPE(ARH1) SUBJECT(PersonID)
.
 
****** END CHAPTER 4 MODELS ******.

* Close output directory.
OUTPUT EXPORT NAME=SPSS_Chapter4_Output
     /CONTENTS EXPORT=VISIBLE LAYERS=VISIBLE MODELVIEWS=VISIBLE
     /HTML DOCUMENTFILE='C:\Dropbox\PilesOfVariance\Chapter4\SPSS\SPSS_Chapter4_Output.html'
           IMAGEFORMAT=PNG STYLING=YES.
